==> dtc_0.25.3.orig.tar.gz: dtc-0.25.3/shared/vars/table_names.php <==
<?php

$pro_mysql_domain_table = "domain";
$pro_mysql_admin_table = "admin";
$pro_mysql_subdomain_table = "subdomain";
$pro_mysql_pop_table = "pop_access";
$pro_mysql_ftp_table = "ftp_access";
$pro_mysql_ssh_table = "ssh_access";
$pro_mysql_client_table = "clients";
$pro_mysql_command_table = "commande";
$pro_mysql_new_command_table = "command_new";
$pro_mysql_config_table = "config";
$pro_mysql_cronjob_table = "cron_job";
$pro_mysql_whois_table = "whois";
$pro_mysql_nameservers_table = "nameservers";
$pro_mysql_handle_table = "handle";
$pro_mysql_product_table = "product";
$pro_mysql_pay_table = "paiement";
$pro_mysql_smtplogs_table = "smtp_logs";
$pro_mysql_new_admin_table = "new_admin";
$pro_mysql_pending_queries_table = "pending_queries";
$pro_mysql_secpayconf_table = "secpayconf";
$pro_mysql_backup_table = "backup";
$pro_mysql_fetchmail_table = "fetchmail";
$pro_mysql_whitelist_table = "whitelist";
$pro_mysql_list_table = "mailinglist";
$pro_mysql_acc_http_table = "http_accounting";
$pro_mysql_acc_ftp_table = "ftp_accounting";
$pro_mysql_acc_email_table = "email_accounting";
$pro_mysql_registry_table = "registry";
$pro_mysql_vps_table = "vps";
$pro_mysql_vps_ip_table = "vps_ip";
$pro_mysql_vps_server_table = "vps_server";
$pro_mysql_pending_renewal_table = "pending_renewal";
$pro_mysql_tik_admins_table = "tik_admins";
$pro_mysql_tik_queries_table = "tik_queries";
$pro_mysql_tik_cats_table = "tik_cats";
$pro_mysql_ssl_ips_table = "ssl_ips";
$pro_mysql_dedicated_table = "dedicated";
$pro_mysql_companies_table = "companies";
$pro_mysql_invoicing_table = "invoicing";
$pro_mysql_completedorders_table = "completedorders";
?>

==> dtc_0.28.10.orig.tar.gz: dtc-0.28.10/shared/vars/table_names.php <==
<?php

$pro_mysql_domain_table = "domain";
$pro_mysql_admin_table = "admin";
$pro_mysql_subdomain_table = "subdomain";
$pro_mysql_pop_table = "pop_access";
$pro_mysql_mailaliasgroup_table = "mailalias";
$pro_mysql_ftp_table = "ftp_access";
$pro_mysql_ssh_table = "ssh_access";
$pro_mysql_client_table = "clients";
$pro_mysql_command_table = "commande";
$pro_mysql_new_command_table = "command_new";
$pro_mysql_config_table = "config";
$pro_mysql_cronjob_table = "cron_job";
$pro_mysql_whois_table = "whois";
$pro_mysql_nameservers_table = "nameservers";
$pro_mysql_handle_table = "handle";
$pro_mysql_product_table = "product";
$pro_mysql_pay_table = "paiement";
$pro_mysql_smtplogs_table = "smtp_logs";
$pro_mysql_new_admin_table = "new_admin";
$pro_mysql_pending_queries_table = "pending_queries";
$pro_mysql_secpayconf_table = "secpayconf";
$pro_mysql_backup_table = "backup";
$pro_mysql_fetchmail_table = "fetchmail";
$pro_mysql_whitelist_table = "whitelist";
$pro_mysql_list_table = "mailinglist";
$pro_mysql_acc_http_table = "http_accounting";
$pro_mysql_acc_ftp_table = "ftp_accounting";
$pro_mysql_acc_email_table = "email_accounting";
$pro_mysql_registry_table = "registry";
$pro_mysql_vps_table = "vps";
$pro_mysql_vps_ip_table = "vps_ip";
$pro_mysql_vps_server_table = "vps_server";
$pro_mysql_vps_stats_table = "vps_stats";
$pro_mysql_vps_server_lists_table = "vps_server_lists";
$pro_mysql_pending_renewal_table = "pending_renewal";
$pro_mysql_tik_admins_table = "tik_admins";
$pro_mysql_tik_queries_table = "tik_queries";
$pro_mysql_tik_cats_table = "tik_cats";
$pro_mysql_ssl_ips_table = "ssl_ips";
$pro_mysql_dedicated_table = "dedicated";
$pro_mysql_companies_table = "companies";
$pro_mysql_invoicing_table = "invoicing";
$pro_mysql_completedorders_table = "completedorders";
?>
